@@ -1,5 +1,5 @@
 /*
- * $Id: dbus.h,v 1.2 2004/04/11 16:11:51 tal197 Exp $
+ * $Id: dbus.h,v 1.3 2004/08/14 15:22:23 tal197 Exp $
  *
  * ROX-Session, a very simple session manager
  * By Thomas Leonard, <tal197@users.sourceforge.net>.
@@ -18,6 +18,6 @@ typedef DBusMessage *(*MessageHandler)(DBusMessage *message, DBusError *error);
 
 /* Prototypes */
 void dbus_init(void);
-gboolean register_object_path(const char **path, MessageHandler handler);
+gboolean register_object_path(const char *path, MessageHandler handler);
 
 #endif /* _DBUS_H */
